@@ -296,6 +296,7 @@ class Enum:
       self.enumname = enum.objname
 
     def __getitem__(self, item):
+      item          = isinstance(item, EnumOption) and item.tag or item
       definition    = self.combined.get(item)
       definition    = definition or isinstance(item, str) and self.combined.get(item.lower())
       if not definition:
@@ -379,3 +380,87 @@ class Enum:
       collection.reverse()
     return collection
 
+
+
+class EnumOption:
+  ''' Smart object that acts like an enum value but remembers which enum it came from.
+
+      There is nothing in the Enum class itself that ever generates these, but you are
+      welcome to instantiate them for your own reasons.  For example, you might define
+      a custom Django field that persists enums by tag but returns EnumOptions at runtime.
+
+      EnumOption is defined here, next to Enum, and not in the hypothetical place where
+      the custom Django field would exist, because Enum.Resolver has to know what an
+      EnumOption is or it can't answer __contains__ tests.
+  '''
+
+  def __init__(self, **kwargs):
+    self.enum       = None
+    self.tag        = None
+    base.utils.SetAttrs(self, **kwargs)
+    if self.enum:
+      if self.tag == '' and None in self.enum:
+        self.tag    = None
+      else:
+        self.tag    = self.enum.Tag(self.tag)
+
+  def __eq__(self, other):
+    if isinstance(other, EnumOption):
+      return (self.enum, self.tag) == (other.enum, other.tag)
+    if self.enum and isinstance(other, type(self.tag)):
+      return self.tag == other
+    return False
+
+  def __lt__(self, other):
+    if isinstance(other, EnumOption):
+      if self.enum == other.enum:
+        return self.index < other.index
+    if self.enum and isinstance(other, type(self.tag)):
+      return self.index < self.enum.Index(other)
+    return False
+
+  def __hash__(self):
+    return hash((self.enum and self.enum.objname or '') + '/' + str(self.tag))
+
+  def __str__(self):
+    return self.tag is not None and str(self.tag) or ''
+
+  def __repr__(self):
+    a, b            = self.appname, self.codename
+    if a and b:
+      return '.'.join((a,b))
+    if b:
+      return b
+    return super().__repr__()
+
+  def __len__(self):
+    return self.tag and len(self.tag) or 0
+
+  @property
+  def definition(self):
+    return self.enum and self.enum.Definition(self.tag) or None
+
+  @property
+  def name(self):
+    return self.enum and self.enum.Name(self.tag) or ''
+
+  @property
+  def icon(self):
+    return self.enum and self.enum.Icon(self.tag) or ''
+
+  @property
+  def index(self):
+    return self.enum and self.enum.Index(self.tag) or 0
+
+  @property
+  def rank(self):
+    return self.enum and self.enum.Rank(self.tag) or 0
+
+  @property
+  def appname(self):
+    return self.enum and self.enum.objname.split('.')[0] or ''
+
+  @property
+  def codename(self):
+    return self.enum and self.enum.Definition(self.tag).codename or ''
+
