@@ -63,5 +63,9 @@ base.utils.ImportCapitalizedNamesFrom(blocknodes, inlinenodes)
 from .highlevel   import RightDownData, RightDownOptions
 
 
+# Finalize the engine
+InitializeAllPatterns()
+
+
 # Register some unit tests
 from . import tests
