@@ -14,7 +14,8 @@ def HumannessFromRecaptcha(request, token, action):
   ''' Makes a query to Google to validate a reCAPTCHA token.
       Returns humanness value 0 .. 1, or None if we're unable to reach Google.
   '''
-  base.utils.ImportDjangoSettingsAndModels()
+
+  from django.conf import settings
 
   GOOGLE          = 'https://www.google.com/recaptcha/api/siteverify'
   INHUMAN         = 0
